@@ -73,12 +73,27 @@ class BulkFilmTable(tables.Table):
     class Meta:
         attrs = {"class": "table table-hover"}
         model = BulkFilm
-        fields = ('id_owner', 'format', 'filmstock')
+        fields = ('id_owner', 'format', 'filmstock', 'length', 'finished')
 
     @classmethod
     def render_id_owner(cls, value):
         return format_html("<a href=\"{}\">#{}</a>", reverse('schema:bulkfilm-detail', args=[value]), value)
 
+    @classmethod
+    def render_finished(cls, value):
+        return format_html(boolicon(value))
+
+    @classmethod
+    def render_format(cls, value):
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:format-detail', args=[value.id]), value)
+
+    @classmethod
+    def render_filmstock(cls, value):
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:filmstock-detail', args=[value.slug]), value)
+
+    @classmethod
+    def render_length(cls, value):
+        return format_html("{}m", value)
 
 class CameraTable(tables.Table):
     class Meta:
@@ -498,7 +513,7 @@ class PrintTable(tables.Table):
 
     @classmethod
     def render_negative(cls, value):
-        return format_html("<a href=\"{}\">{}</a>", reverse('schema:negative-detail', args=[value.id_owner]), value)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:negative-detail', args=[value.slug]), value)
 
 
 class ProcessTable(tables.Table):
@@ -532,7 +547,7 @@ class ScanTable(tables.Table):
 
     @classmethod
     def render_negative(cls, value):
-        return format_html("<a href=\"{}\">{}</a>", reverse('schema:negative-detail', args=[value.id_owner]), value)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:negative-detail', args=[value.slug]), value)
 
     @classmethod
     def render_print(cls, value):
@@ -547,12 +562,23 @@ class NegativeTable(tables.Table):
     class Meta:
         attrs = {"class": "table table-hover"}
         model = Negative
-        fields = ('id_owner', 'date', 'lens', 'shutter_speed', 'aperture')
+        fields = ('slug', 'film', 'date', 'lens', 'shutter_speed', 'aperture')
 
     @classmethod
-    def render_id_owner(cls, value, record):
+    def render_slug(cls, value, record):
         return format_html("<a href=\"{}\">{}</a>", reverse('schema:negative-detail', args=[value]), record)
 
+    @classmethod
+    def render_aperture(cls, value):
+        return format_html("<em>f</em>/{}", value)
+
+    @classmethod
+    def render_film(cls, value):
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:film-detail', args=[value.id_owner]), value)
+
+    @classmethod
+    def render_lens(cls, value):
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:lens-detail', args=[value.id_owner]), value)
 
 class FilmTable(tables.Table):
     class Meta:
@@ -589,7 +615,7 @@ class TeleconverterTable(tables.Table):
         return format_html("<a href=\"{}\">#{}</a>", reverse('schema:teleconverter-detail', args=[value]), value)
 
     @classmethod
-    def render_model(cls, value, record):
+    def render_teleconvertermodel(cls, value, record):
         return format_html("<a href=\"{}\">{}</a>", reverse('schema:teleconvertermodel-detail', args=[record.teleconvertermodel.slug]), value)
 
 
@@ -613,6 +639,9 @@ class TeleconverterModelTable(tables.Table):
     def render_factor(cls, value):
         return format_html("{}&times;", value)
 
+    @classmethod
+    def render_mount(cls, value):
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:mount-detail', args=[value.slug]), value)
 
 class TonerTable(tables.Table):
     class Meta:
